/**
 * @file
 * Supporting JS for the menu parent item form element.
 */

(function($) {
  Drupal.behaviors.menu_select = {
    attach: function(context, settings) {
      $('.form-item-menu-parent', context).once(function() {
        $(this).hide();
        $('#edit-menu-menu-select').removeClass('element-invisible');

        $('#edit-menu-menu-select-select-menu-link-position-parent-menu').change(function(e) {
          menu_select_build_menu_hierarchy($(this).val());
          menu_select_build_position_preview($(this).val());
          $('.parent-menu').text(Drupal.settings.menu_select.map[$(this).val()]);
        });

        menu_select_build_menu_hierarchy($('#edit-menu-menu-select-select-menu-link-position-parent-menu').val());

        var selected = $('li[data-mkey="' + $('#edit-menu-parent').val() + '"]');
        selected.find('> a').click();
        var parents = selected.parents('.has-children');

        for (var i = 0; i < parents.length; i++) {
          menu_select_reveal_level({}, $(parents[i]).find('> span.toggle'));
        }

        $('#edit-menu-menu-select-select-menu-link-position-parent-menu-item-search').bind('autocompleteSelect', function() {
          var mkey = $(this).val();
          var mkey_parts = mkey.split(':');
          $('#edit-menu-menu-select-select-menu-link-position-parent-menu').val(mkey_parts[0] + ':0').change();

          var selected = $('li[data-mkey="' + mkey + '"]');
          selected.find('> a').click();
          var parents = selected.parents('.has-children');

          for (var i = 0; i < parents.length; i++) {
            menu_select_reveal_level({}, $(parents[i]).find('> span.toggle'));
          }
        });
      });
    }
  }

  /**
   * Function to show/hide children.
   */
  function menu_select_reveal_level(e, level) {
    if (typeof(level) === 'undefined') {
      level = this;
    }

    if ($(level).children('.icon-caret-right').length > 0) {
      $(level).siblings('ul').show();
      $(level).children().removeClass().addClass('icon-caret-down-two');
    } else {
      $(level).siblings('ul').hide();
      $(level).children().removeClass().addClass('icon-caret-right');
    }
  }

  /**
   * Build the menu hierarchy.
   */
  function menu_select_build_menu_hierarchy(root) {
    var map = Drupal.settings.menu_select.map;
    var menu = Drupal.settings.menu_select.menu[root];
    var output = _menu_select_hierarchy_recurse(menu, map);

    $('.menu-hierarchy').html('<div class="root"><i class="icon-caret-down-two"></i><a href="#" class="menu-parent-selection selected">' + Drupal.settings.menu_select.map[root] + '</a></div>' + output);

    if ($('.menu-hierarchy li').length > Drupal.settings.menu_select.cut_off) {
      $('.menu-hierarchy > ul').addClass('start-collapsed');
    }

    $('.menu-parent-selection').click(function(e) {
      e.preventDefault();

      var label = $(this).text();
      var mkey = $(this).parent().attr('data-mkey');

      $('.form-item-menu-parent select').val(mkey);

      menu_select_build_position_preview(mkey);

      $('.menu-hierarchy .selected').removeClass('selected');
      $(this).addClass('selected');

      $(this).siblings('span.toggle').click();

      return false;
    });

    $('.has-children > .toggle').click(menu_select_reveal_level);
  }

  /**
   * Prepare the menu output.
   */
  function _menu_select_hierarchy_recurse(level, map) {
    var output = '';
    for (var mkey in level) {
      var has_children = (level[mkey].length !== 0);
      var classes = '';

      if (has_children) {
        classes += ' has-children';
      }

      output += '<li data-mkey="' + mkey + '" class="' + classes + '"><span class="toggle"><i class="icon-caret-down-two"></i></span><span class="item"><i class="icon-circle"></i></span><a href="#" class="menu-parent-selection">' + map[mkey] + '</a>';
      
      if (has_children) {
        output += _menu_select_hierarchy_recurse(level[mkey], map);
      }
      
      output += '</li>';
    }
    
    return '<ul>' + output + '</ul>';
  }

  /**
   * Build the menu position preview.
   */
  function menu_select_build_position_preview(mkey) {
    var map = Drupal.settings.menu_select.map;
    var menu_element = $('li[data-mkey="' + mkey + '"]');
    var parents = $(menu_element).parents('li');

    $('.position-preview').html('');

    for (var i = parents.length - 1; i >= 0; i--) {
      $('.position-preview').append('<span>' + $(parents[i]).find('> a').text() + '</span> / ');
    }

    if (menu_element.length === 1) {
      $('.position-preview').append('<span>' + menu_element.find('> a').text() + '</span> / ');
    }
  }
})(jQuery);
